@@ -226,6 +226,20 @@ test_that("set_attribute_names() and get_attribute_names()", {
 })
 
 
+test_that("set_attribute_names() and get_attribute_names()", {
+  expect_equal({
+    new <- "species"
+    names(new) <- "Species"
+    ft <- flat_table('iris', iris) |>
+      set_attribute_names(
+        new = new)
+    c(ft$operations$operation$operation,
+      ft |>
+        get_attribute_names())
+  }, c("flat_table", "set_attribute_names", "species"))
+})
+
+
 test_that("set_measure_names() and get_measure_names()", {
   expect_equal({
     ft <- flat_table('iris', iris) |>
@@ -244,6 +258,20 @@ test_that("set_measure_names() and get_measure_names()", {
   }, c("flat_table", "set_measure_names", "ls", "sw", "pl", "pw"))
 })
 
+
+test_that("set_measure_names() and get_measure_names()", {
+  expect_equal({
+    new <- c('pl', 'pw', 'ls', 'sw')
+    names(new) <- c('Petal.Length', 'Petal.Width', 'Sepal.Length', 'Sepal.Width')
+    ft <- flat_table('iris', iris) |>
+      set_measure_names(
+        new = new)
+    c(ft$operations$operation$operation,
+      ft |>
+        get_measure_names())
+  }, c("flat_table", "set_measure_names", "ls", "sw", "pl", "pw"))
+})
+
 test_that("get_similar_attribute_values()", {
   expect_equal({
     ft <- flat_table('iris', iris)
